NELSNMP: A wrapper module for pysnmp
====================================

Nelsnmp is used by `nelmon`_ and the `Cisco SNMP Ansible modules <http://networklore.com/ansible-cisco-snmp/>`_.

.. _`nelmon`: http://networklore.com/nelmon/
